# -*- coding: utf-8 -*-
"""
    zebe.service.ad
    ~~~~~~~~~~~~~~~~

    广告相关的服务

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""

from zebe.modle.entity.ad import Ad, AdModelSession
from zebe.service.base import ModelBaseService


# 广告服务
class AdService(ModelBaseService):
    def __init__(self):
        super().__init__(Ad, AdModelSession)



# -*- coding: utf-8 -*-
"""
    zebe.service.english
    ~~~~~~~~~~~~~~~~

    英语相关的服务

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""

from zebe.modle.entity.english import EnglishPhrase, EnglishModelSession
from zebe.service.base import ModelBaseService


# 英语短语服务
class EnglishPhraseService(ModelBaseService):
    def __init__(self):
        super().__init__(EnglishPhrase, EnglishModelSession)

    # 通过首字母查找短语
    def find_all_by_first_letter(self, first_letter):
        result = None
        if first_letter is not None:
            result = self.session.query(self.entity).filter(self.entity.first_letter == first_letter).all()
            self.session.close()
        return result



# -*- coding: utf-8 -*-
"""
    zebe.service.remind
    ~~~~~~~~~~~~~~~~

    提醒相关的服务

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""
from zebe.modle.entity.remind import Remind, RemindModelSession
from zebe.service.base import ModelBaseService


# 提醒服务
class RemindService(ModelBaseService):
    def __init__(self):
        super().__init__(Remind, RemindModelSession)

    # 按照模式查询项目
    def find_by_mode(self, mode):
        result = self.session.query(self.entity).filter(self.entity.mode == mode).all()
        self.session.close()
        return result



# -*- coding: utf-8 -*-
"""
    zebe.config.db
    ~~~~~~~~~~~~~~~~

    常量配置

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""

MAIL_SMTP_PORT = 465
MAIL_SMTP_HOST = "smtp.qq.com"
MAIL_SENDER = 'zebe-notify@qq.com'
MAIL_PASSWORD = 'nramfouoyhkcdfjh'
MAIL_RECEIVER_ZEBE = 'zebe@vip.qq.com'
MAIL_RECEIVER_JULY = '1239571962@qq.com'



# -*- coding: utf-8 -*-
"""
    zebe.service.memory
    ~~~~~~~~~~~~~~~~

    记忆相关的服务

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""

from zebe.modle.entity.memory import NumberCode, MemoryModelModelSession
from zebe.service.base import ModelBaseService


class NumberCodeService(ModelBaseService):

    def __init__(self):
        super().__init__(NumberCode, MemoryModelModelSession)

    def find_one_by_number(self, number):
        """
        通过数字查找一条记录
        :param number: 数字
        :return:
        """
        result = self.session.query(self.entity).filter(self.entity.number == number).one_or_none()
        self.session.close()
        return result

    def get_all_number_code_dict(self):
        """
        获取所有数字和编码的对应字典
        :return:
        """
        result = {}
        numbers = self.find_all()
        for data in numbers:
            result[data.number] = data.code
        return result



# -*- coding: utf-8 -*-
"""
    zebe.service.cdrvba
    ~~~~~~~~~~~~~~~~

    CorelDrawVBA相关的服务

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""

from zebe.modle.entity.cdrvba import CorelDrawVBAArticle, CorelDrawVBAModelSession

from zebe.service.base import ModelBaseService


# CorelDrawVBA文章服务
class CorelDrawVBAArticleService(ModelBaseService):
    def __init__(self):
        super().__init__(CorelDrawVBAArticle, CorelDrawVBAModelSession)

    # 查询全部数据并按照日期倒序排列
    def find_all_ordered_by_time(self):
        result = self.session.query(self.entity).order_by(self.entity.create_time.desc()).all()
        self.session.close()
        return result

    # 查询指定类型的数据并按照日期倒序排列
    def find_all_by_type(self, data_type):
        result = self.session.query(self.entity).filter(self.entity.type == data_type).order_by(self.entity.create_time.desc()).all()
        self.session.close()
        return result

    # 查询指定标签的数据并按照日期倒序排列
    def find_all_by_tag(self, tag):
        result = self.session.query(self.entity).filter(self.entity.tags.like(tag + "%")).order_by(
            self.entity.create_time.desc()).all()
        self.session.close()
        return result
